@@ -22,20 +22,26 @@ import sys
 import tempfile
 import unittest
 
+import six
+
 from ironic_inspector.common import swift
 from ironic_inspector import introspection_state as istate
 from ironic_inspector.test import functional
+from keystoneauth1 import session as ks_session
+from keystoneauth1 import token_endpoint
 from oslo_concurrency import processutils
 
 import ironic_inspector_client as client
-from ironic_inspector_client.common import http
 from ironic_inspector_client import shell
 
 
 class TestV1PythonAPI(functional.Base):
     def setUp(self):
         super(TestV1PythonAPI, self).setUp()
-        self.client = client.ClientV1()
+        self.auth = token_endpoint.Token(endpoint='http://127.0.0.1:5050',
+                                         token='token')
+        self.session = ks_session.Session(self.auth)
+        self.client = client.ClientV1(session=self.session)
         functional.cfg.CONF.set_override('store_data', 'none', 'processing')
 
     def my_status_index(self, statuses):
@@ -184,18 +190,6 @@ class TestV1PythonAPI(functional.Base):
         # assert continue doesn't work after abort
         self.call_continue(self.data, expect_error=400)
 
-    def test_setup_ipmi(self):
-        self.node.provision_state = 'enroll'
-        self.client.introspect(self.uuid, new_ipmi_username='admin',
-                               new_ipmi_password='pwd')
-        eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
-        self.assertFalse(self.cli.node.set_power_state.called)
-
-        res = self.call_continue(self.data)
-        self.assertEqual('admin', res['ipmi_username'])
-        self.assertEqual('pwd', res['ipmi_password'])
-        self.assertTrue(res['ipmi_setup_credentials'])
-
     def test_api_versions(self):
         minv, maxv = self.client.server_api_versions()
         self.assertEqual((1, 0), minv)
@@ -204,15 +198,18 @@ class TestV1PythonAPI(functional.Base):
 
     def test_client_init(self):
         self.assertRaises(client.VersionNotSupported,
-                          client.ClientV1, api_version=(1, 999))
+                          client.ClientV1, session=self.session,
+                          api_version=(1, 999))
         self.assertRaises(client.VersionNotSupported,
-                          client.ClientV1, api_version=2)
+                          client.ClientV1, session=self.session,
+                          api_version=2)
 
-        self.assertTrue(client.ClientV1(api_version=1).server_api_versions())
-        self.assertTrue(client.ClientV1(api_version='1.0')
-                        .server_api_versions())
-        self.assertTrue(client.ClientV1(api_version=(1, 0))
-                        .server_api_versions())
+        self.assertTrue(client.ClientV1(
+            api_version=1, session=self.session).server_api_versions())
+        self.assertTrue(client.ClientV1(
+            api_version='1.0', session=self.session).server_api_versions())
+        self.assertTrue(client.ClientV1(
+            api_version=(1, 0), session=self.session).server_api_versions())
 
         self.assertTrue(
             client.ClientV1(inspector_url='http://127.0.0.1:5050')
@@ -221,9 +218,6 @@ class TestV1PythonAPI(functional.Base):
             client.ClientV1(inspector_url='http://127.0.0.1:5050/v1')
             .server_api_versions())
 
-        self.assertTrue(client.ClientV1(auth_token='some token')
-                        .server_api_versions())
-
     def test_rules_api(self):
         res = self.client.rules.get_all()
         self.assertEqual([], res)
@@ -271,43 +265,6 @@ class TestV1PythonAPI(functional.Base):
                           self.uuid)
 
 
-class TestSimplePythonAPI(functional.Base):
-    def test_introspect_get_status(self):
-        client.introspect(self.uuid)
-        eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
-        self.cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                              'reboot')
-
-        status = client.get_status(self.uuid)
-        self.check_status(status, finished=False, state=istate.States.waiting)
-
-        res = self.call_continue(self.data)
-        self.assertEqual({'uuid': self.uuid}, res)
-        eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
-
-        self.assertCalledWithPatch(self.patch, self.cli.node.update)
-        self.cli.port.create.assert_called_once_with(
-            node_uuid=self.uuid, address='11:22:33:44:55:66',
-            pxe_enabled=True, extra={})
-
-        status = client.get_status(self.uuid)
-        self.check_status(status, finished=True, state=istate.States.finished)
-
-    def test_api_versions(self):
-        minv, maxv = client.server_api_versions()
-        self.assertEqual((1, 0), minv)
-        self.assertGreaterEqual(maxv, (1, 0))
-        self.assertLess(maxv, (2, 0))
-
-        self.assertRaises(client.VersionNotSupported,
-                          client.introspect, self.uuid, api_version=(1, 999))
-        self.assertRaises(client.VersionNotSupported,
-                          client.get_status, self.uuid, api_version=(1, 999))
-        # Error 404
-        self.assertRaises(client.ClientError,
-                          client.get_status, self.uuid, api_version=(1, 0))
-
-
 BASE_CMD = [os.path.join(sys.prefix, 'bin', 'openstack'),
             '--os-auth-type', 'token_endpoint', '--os-token', 'fake',
             '--os-url', 'http://127.0.0.1:5050']
@@ -377,20 +334,21 @@ class TestCLI(BaseCLITest):
         return fake_status
 
     def test_cli_negative(self):
+        if six.PY3:
+            msg_missing_param = 'the following arguments are required'
+        else:
+            msg_missing_param = 'too few arguments'
         err = self.run_cli('start', expect_error=True)
-        self.assertIn('too few arguments', err)
+        self.assertIn(msg_missing_param, err)
         err = self.run_cli('status', expect_error=True)
-        self.assertIn('too few arguments', err)
-        err = self.run_cli('start', 'uuid', '--new-ipmi-username', 'user',
-                           expect_error=True)
-        self.assertIn('requires a new password', err)
+        self.assertIn(msg_missing_param, err)
         err = self.run_cli('rule', 'show', 'uuid', expect_error=True)
         self.assertIn('not found', err)
         err = self.run_cli('rule', 'delete', 'uuid', expect_error=True)
         self.assertIn('not found', err)
 
         err = self.run_cli('interface', 'list', expect_error=True)
-        self.assertIn('too few arguments', err)
+        self.assertIn(msg_missing_param, err)
 
     def test_introspect_get_status(self):
         self.run_cli('start', self.uuid)
@@ -421,7 +379,7 @@ class TestCLI(BaseCLITest):
                 'actions': [{'action': 'fail', 'message': 'boom'}],
                 'description': 'Cool actions',
                 'uuid': self.uuid}
-        with tempfile.NamedTemporaryFile() as fp:
+        with tempfile.NamedTemporaryFile(mode='w') as fp:
             json.dump(rule, fp)
             fp.flush()
             res = self.run_cli('rule', 'import', fp.name, parse_json=True)
@@ -441,7 +399,7 @@ class TestCLI(BaseCLITest):
         res = self.run_cli('rule', 'list', parse_json=True)
         self.assertEqual([], res)
 
-        with tempfile.NamedTemporaryFile() as fp:
+        with tempfile.NamedTemporaryFile(mode='w') as fp:
             rule.pop('uuid')
             json.dump([rule, rule], fp)
             fp.flush()
@@ -468,23 +426,21 @@ class TestCLI(BaseCLITest):
                          u'Switch Port VLAN IDs': [101, 102, 106]}
 
         res = self.run_cli('interface', 'list', self.uuid, parse_json=True)
-        res.sort()
-        self.assertEqual(expected_eth1, res[0])
-        self.assertEqual(expected_eth3, res[1])
+        self.assertIn(expected_eth1, res)
+        self.assertIn(expected_eth3, res)
 
         # Filter on vlan
         res = self.run_cli('interface', 'list', self.uuid, '--vlan', '106',
                            parse_json=True)
-        res.sort()
-        self.assertEqual(expected_eth3, res[0])
+        self.assertIn(expected_eth3, res)
 
         # Select fields
         res = self.run_cli('interface', 'list', self.uuid, '--fields',
                            'switch_port_mtu',
                            parse_json=True)
-        res.sort()
-        self.assertEqual({u'Switch Port MTU': 1514}, res[0])
-        self.assertEqual({u'Switch Port MTU': 9216}, res[1])
+
+        self.assertIn({u'Switch Port MTU': 1514}, res)
+        self.assertIn({u'Switch Port MTU': 9216}, res)
 
     @mock.patch.object(swift, 'get_introspection_data', autospec=True)
     def test_interface_show(self, get_mock):
@@ -510,6 +466,4 @@ class TestCLI(BaseCLITest):
 
 if __name__ == '__main__':
     with functional.mocked_server():
-        # Make links predictable
-        http._DEFAULT_URL = 'http://127.0.0.1:5050'
         unittest.main(verbosity=2)
