@@ -13,7 +13,7 @@
 
 import sys
 
-from collections import OrderedDict
+import collections
 import mock
 from osc_lib.tests import utils
 import six
@@ -230,6 +230,32 @@ class TestRules(BaseTest):
         self.rules_api.from_json.assert_any_call({'foo': 'bar'})
         self.rules_api.from_json.assert_any_call({'answer': 42})
 
+    def test_import_yaml(self):
+        f = tempfile.NamedTemporaryFile()
+        self.addCleanup(f.close)
+        f.write(b"""---
+- foo: bar
+- answer: 42
+""")
+        f.flush()
+
+        arglist = [f.name]
+        verifylist = [('file', f.name)]
+
+        self.rules_api.from_json.side_effect = iter([
+            {'uuid': '1', 'description': 'd1', 'links': []},
+            {'uuid': '2', 'description': 'd2', 'links': []}
+        ])
+
+        cmd = shell.RuleImportCommand(self.app, None)
+        parsed_args = self.check_parser(cmd, arglist, verifylist)
+        cols, values = cmd.take_action(parsed_args)
+
+        self.assertEqual(('UUID', 'Description'), cols)
+        self.assertEqual([('1', 'd1'), ('2', 'd2')], values)
+        self.rules_api.from_json.assert_any_call({'foo': 'bar'})
+        self.rules_api.from_json.assert_any_call({'answer': 42})
+
     def test_list(self):
         self.rules_api.get_all.return_value = [
             {'uuid': '1', 'description': 'd1', 'links': []},
@@ -438,7 +464,7 @@ class TestInterfaceCmds(BaseTest):
     def test_show(self):
         self.client.get_data.return_value = self.inspector_db
 
-        data = OrderedDict(
+        data = collections.OrderedDict(
             [('node_ident', "uuid1"),
              ('interface', "em1"),
              ('mac', "00:11:22:33:44:55"),
@@ -480,15 +506,15 @@ class TestInterfaceCmds(BaseTest):
     def test_show_field(self):
         self.client.get_data.return_value = self.inspector_db
 
-        data = OrderedDict([('node_ident', "uuid1"),
-                            ('interface', "em1"),
-                            ('switch_port_vlans',
-                             [{"id": 101, "name": "vlan101"},
-                              {"id": 102, "name": "vlan102"},
-                              {"id": 104, "name": "vlan104"},
-                              {"id": 201, "name": "vlan201"},
-                              {"id": 203, "name": "vlan203"}])
-                            ])
+        data = collections.OrderedDict([('node_ident', "uuid1"),
+                                        ('interface', "em1"),
+                                        ('switch_port_vlans',
+                                         [{"id": 101, "name": "vlan101"},
+                                          {"id": 102, "name": "vlan102"},
+                                          {"id": 104, "name": "vlan104"},
+                                          {"id": 201, "name": "vlan201"},
+                                          {"id": 203, "name": "vlan203"}])
+                                        ])
 
         self.client.get_interface_data.return_value = data
 
