@@ -84,11 +84,18 @@ class TestIntrospect(BaseTest):
     def test(self, mock_req):
         self.get_client().introspect(self.uuid)
         mock_req.assert_called_once_with(
-            'post', '/introspection/%s' % self.uuid)
+            'post', '/introspection/%s' % self.uuid,
+            params={})
 
     def test_invalid_input(self, mock_req):
         self.assertRaises(TypeError, self.get_client().introspect, 42)
 
+    def test_manage_boot(self, mock_req):
+        self.get_client().introspect(self.uuid, manage_boot=False)
+        mock_req.assert_called_once_with(
+            'post', '/introspection/%s' % self.uuid,
+            params={'manage_boot': '0'})
+
 
 @mock.patch.object(http.BaseClient, 'request')
 class TestReprocess(BaseTest):
@@ -427,8 +434,7 @@ class TestInterfaceApi(BaseTest):
             self.uuid, "em1", fields)
         self.assertEqual(expected_values, iface_dict)
 
-        # Test interface name not in 'all_interfaces'
-        expected_values = collections.OrderedDict()
-        iface_dict = self.get_client().get_interface_data(
-            self.uuid, "em55", fields)
-        self.assertEqual(expected_values, iface_dict)
+    def test_invalid_interface(self, mock_req):
+        mock_req.return_value.json.return_value = self.inspector_db
+        self.assertRaises(ValueError, self.get_client().get_interface_data,
+                          self.uuid, "em55", ["node_ident", "interface"])
