@@ -13,7 +13,7 @@
 
 """Client for V1 API."""
 
-from collections import OrderedDict
+import collections
 import logging
 import time
 
@@ -26,7 +26,7 @@ from ironic_inspector_client.common.i18n import _
 DEFAULT_API_VERSION = (1, 0)
 """Server API version used by default."""
 
-MAX_API_VERSION = (1, 8)
+MAX_API_VERSION = (1, 13)
 """Maximum API version this client was designed to work with.
 
 This does not mean that other versions won't work at all - the server might
@@ -88,28 +88,40 @@ class ClientV1(http.BaseClient):
         super(ClientV1, self).__init__(**kwargs)
         self.rules = RulesAPI(self.request)
 
-    def introspect(self, uuid):
+    def introspect(self, uuid, manage_boot=None):
         """Start introspection for a node.
 
         :param uuid: node UUID or name
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :param manage_boot: whether to manage boot during introspection of
+            this node. If it is None (the default), then this argument is not
+            passed to API and the server default is used instead.
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         :raises: *requests* library exception on connection problems.
         """
         if not isinstance(uuid, six.string_types):
             raise TypeError(
                 _("Expected string for uuid argument, got %r") % uuid)
 
-        self.request('post', '/introspection/%s' % uuid)
+        params = {}
+        if manage_boot is not None:
+            params['manage_boot'] = str(int(manage_boot))
+
+        self.request('post', '/introspection/%s' % uuid, params=params)
 
     def reprocess(self, uuid):
         """Reprocess stored introspection data.
 
+        If swift support is disabled, introspection data won't be stored,
+        this request will return error response with 404 code.
+
         :param uuid: node UUID or name.
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         :raises: *requests* library exception on connection problems.
         :raises: TypeError if uuid is not a string.
         """
@@ -130,9 +142,10 @@ class ClientV1(http.BaseClient):
 
         :param marker: pagination maker, UUID or None
         :param limit: pagination limit, int or None
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         :raises: *requests* library exception on connection problems.
         :return: a list of status dictionaries with the keys:
 
@@ -161,9 +174,10 @@ class ClientV1(http.BaseClient):
         """Get introspection status for a node.
 
         :param uuid: node UUID or name.
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported`
+            if requested api_version is not supported
         :raises: *requests* library exception on connection problems.
         :return: dictionary with the keys:
 
@@ -189,10 +203,12 @@ class ClientV1(http.BaseClient):
         :param retry_interval: sleep interval between retries.
         :param max_retries: maximum number of retries.
         :param sleep_function: function used for sleeping between retries.
-        :raises: :py:class:`.WaitTimeoutError` on timeout
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.WaitTimeoutError` on
+            timeout
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         :raises: *requests* library exception on connection problems.
         :return: dictionary UUID -> status (the same as in get_status).
         """
@@ -227,12 +243,16 @@ class ClientV1(http.BaseClient):
     def get_data(self, uuid, raw=False):
         """Get introspection data from the last introspection of a node.
 
+        If swift support is disabled, introspection data won't be stored,
+        this request will return error response with 404 code.
+
         :param uuid: node UUID or name.
         :param raw: whether to return raw binary data or parsed JSON data
         :returns: bytes or a dict depending on the 'raw' argument
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         :raises: *requests* library exception on connection problems.
         :raises: TypeError if uuid is not a string
         """
@@ -250,9 +270,10 @@ class ClientV1(http.BaseClient):
         """Abort running introspection for a node.
 
         :param uuid: node UUID or name.
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         :raises: *requests* library exception on connection problems.
         :raises: TypeError if uuid is not a string.
         """
@@ -276,7 +297,7 @@ class ClientV1(http.BaseClient):
         :raises: ValueError if interface is not found.
         """
         # Use OrderedDict to maintain order of user-entered fields
-        iface_data = OrderedDict()
+        iface_data = collections.OrderedDict()
 
         data = self.get_data(node_ident)
         all_interfaces = data.get('all_interfaces', [])
@@ -362,9 +383,10 @@ class RulesAPI(object):
         :param uuid: rule UUID, will be generated if not specified
         :param description: optional rule description
         :returns: rule representation
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         """
         if uuid is not None and not isinstance(uuid, six.string_types):
             raise TypeError(
@@ -386,9 +408,10 @@ class RulesAPI(object):
         :param json_rule: rule information as a dict with keys matching
             arguments of :py:meth:`RulesAPI.create`.
         :returns: rule representation
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         """
         return self._request('post', '/rules', json=json_rule).json()
 
@@ -397,9 +420,10 @@ class RulesAPI(object):
 
         :returns: list of short rule representations (uuid, description
                   and links)
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         """
         return self._request('get', '/rules').json()['rules']
 
@@ -408,9 +432,10 @@ class RulesAPI(object):
 
         :param uuid: rule UUID
         :returns: rule representation
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         """
         if not isinstance(uuid, six.string_types):
             raise TypeError(
@@ -421,9 +446,10 @@ class RulesAPI(object):
         """Delete an introspection rule.
 
         :param uuid: rule UUID
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         """
         if not isinstance(uuid, six.string_types):
             raise TypeError(
@@ -433,8 +459,9 @@ class RulesAPI(object):
     def delete_all(self):
         """Delete all introspection rules.
 
-        :raises: :py:class:`.ClientError` on error reported from a server
-        :raises: :py:class:`.VersionNotSupported` if requested api_version
-            is not supported
+        :raises: :py:class:`ironic_inspector_client.ClientError` on error
+            reported from a server
+        :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
+            requested api_version is not supported
         """
         self._request('delete', '/rules')
